@@ -1,38 +1,41 @@
 ;;; erc-ezbounce.el ---  Handle EZBounce bouncer commands
 
-;; Copyright (C) 2002  Andreas Fuchs <asf@void.at>
+;; Copyright (C) 2002, 2004, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: Andreas Fuchs <asf@void.at>
 ;; Keywords: comm
 
-;; This file is free software; you can redistribute it and/or modify
+;; This file is part of GNU Emacs.
+
+;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
-;; This file is distributed in the hope that it will be useful,
+;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with GNU Emacs; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
-;; 
-
 ;;; Code:
 
 (require 'erc)
+(eval-when-compile (require 'cl))
 
-(defconst erc-ezb-version "$Revision: 1.4 $"
-  "ERC EZBouncer revision.")
+(defgroup erc-ezbounce nil
+  "Interface to the EZBounce IRC bouncer (a virtual IRC server)"
+  :group 'erc)
 
 (defcustom erc-ezb-regexp "^ezbounce!srv$"
   "Regexp used by the EZBouncer to identify itself to the user."
+  :group 'erc-ezbounce
   :type 'string)
 
 (defcustom erc-ezb-login-alist '()
@@ -43,6 +46,7 @@ The alist's format is as follows:
  (((server . port) . (username . password))
   ((server . port) . (username . password))
   ...)"
+  :group 'erc-ezbounce
   :type '(repeat
 	  (cons (cons :tag "Server"
 		     string
@@ -61,23 +65,22 @@ The alist's format is as follows:
 
 (defvar erc-ezb-session-list '()
   "List of detached EZBounce sessions.")
+(make-variable-buffer-local 'erc-ezb-session-list)
 
 (defvar erc-ezb-inside-session-listing nil
   "Indicate whether current notices are expected to be EZB session listings.")
 
-(make-variable-buffer-local 'erc-ezb-session-list)
-
 ;;;###autoload
 (defun erc-cmd-ezb (line &optional force)
   "Send EZB commands to the EZBouncer verbatim."
-  (erc-send-command (concat "EZB " line)))
+  (erc-server-send (concat "EZB " line)))
 (put 'erc-cmd-EZB 'do-not-parse-args t)
 
 ;;;###autoload
 (defun erc-ezb-get-login (server port)
   "Return an appropriate EZBounce login for SERVER and PORT.
 Look up entries in `erc-ezb-login-alist'. If the username or password
-in the alist is `nil', prompt for the apropriate values."
+in the alist is `nil', prompt for the appropriate values."
   (let ((login (cdr (assoc (cons server port) erc-ezb-login-alist))))
     (when login
       (let ((username (car login))
@@ -104,8 +107,8 @@ in the alist is `nil', prompt for the apropriate values."
 ;;;###autoload
 (defun erc-ezb-notice-autodetect (proc parsed)
   "React on an EZBounce NOTICE request."
-  (let* ((sender (aref parsed 1))
-	 (message (aref parsed 3))
+  (let* ((sender (erc-response.sender parsed))
+	 (message (erc-response.contents parsed))
 	 (function (erc-ezb-lookup-action message)))
     (when (and (string-match erc-ezb-regexp sender)
 	       function)
@@ -119,11 +122,11 @@ in the alist is `nil', prompt for the apropriate values."
     (unless (null login)
       (let ((username (car login))
 	    (pass (cdr login)))
-	(erc-send-command (concat "LOGIN " username " " pass))))))
+	(erc-server-send (concat "LOGIN " username " " pass))))))
 
 ;;;###autoload
 (defun erc-ezb-init-session-list (message)
-  "Reset the EZBounce session list to NIL."
+  "Reset the EZBounce session list to nil."
   (setq erc-ezb-session-list nil)
   (setq erc-ezb-inside-session-listing t))
 
@@ -131,12 +134,12 @@ in the alist is `nil', prompt for the apropriate values."
 (defun erc-ezb-end-of-session-list (message)
   "Indicate the end of the EZBounce session listing."
   (setq erc-ezb-inside-session-listing nil))
-  
+
 ;;;###autoload
 (defun erc-ezb-add-session (message)
   "Add an EZBounce session to the session list."
   (when (and erc-ezb-inside-session-listing
-	     (string-match "^\\([^ ]+\\) +\\([^ ]+\\) +\\([^ ]+\\) +\\([^ ]+\\)$" message))
+	     (string-match "^\\([^ \n]+\\) +\\([^ \n]+\\) +\\([^ \n]+\\) +\\([^ \n]+\\)$" message))
     (let ((id (match-string 1 message))
 	  (nick (match-string 2 message))
 	  (to   (match-string 3 message)))
@@ -153,8 +156,8 @@ in the alist is `nil', prompt for the apropriate values."
 	    (erc-string-to-port
 	     (read-from-minibuffer "IRC port: "
 				   (erc-port-to-string "6667")))))
-      (erc-send-command (format "CONN %s %s" server port)))))
-    
+      (erc-server-send (format "CONN %s %s" server port)))))
+
 
 ;;;###autoload
 (defun erc-ezb-select-session ()
@@ -163,14 +166,15 @@ in the alist is `nil', prompt for the apropriate values."
 			       erc-ezb-session-list)))
     (if (string= session "")
 	nil
-      (erc-send-command (format "REATTACH %s" session)))))
+      (erc-server-send (format "REATTACH %s" session)))))
 
 
 ;;;###autoload
 (defun erc-ezb-initialize ()
   "Add EZBouncer convenience functions to ERC."
-  (add-hook 'erc-server-NOTICE-hook 'erc-ezb-notice-autodetect))
-	
+  (add-hook 'erc-server-NOTICE-functions 'erc-ezb-notice-autodetect))
+
 (provide 'erc-ezbounce)
 
+;; arch-tag: e972aa7b-a9f4-4d16-a489-074ec7a1002e
 ;;; erc-ezbounce.el ends here
