@@ -1,25 +1,29 @@
 ;; erc-goodies.el --- Collection of ERC modules
 
-;; Copyright (C) 2001,2002,2003,2004,2005 Free Software Foundation
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
+;;   Free Software Foundation, Inc.
 
 ;; Author: Jorgen Schaefer <forcer@forcix.cx>
 
 ;; Most code is taken verbatim from erc.el, see there for the original
 ;; authors.
 
-;; This program is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2 of the License, or
-;; (at your option) any later version.
+;; This file is part of GNU Emacs.
 
-;; This program is distributed in the hope that it will be useful,
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
+
+;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+;; along with GNU Emacs; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -29,10 +33,14 @@
 
 (require 'erc)
 
-;; Imenu Autoload
-(add-hook 'erc-mode-hook
-	  (lambda ()
-	    (setq imenu-create-index-function 'erc-create-imenu-index)))
+;;; Imenu support
+
+(defun erc-imenu-setup ()
+  "Setup Imenu support in an ERC buffer."
+  (set (make-local-variable 'imenu-create-index-function)
+       'erc-create-imenu-index))
+
+(add-hook 'erc-mode-hook 'erc-imenu-setup)
 (autoload 'erc-create-imenu-index "erc-imenu" "Imenu index creation function")
 
 ;;; Automatically scroll to bottom
@@ -47,11 +55,15 @@ argument to `recenter'."
   :type '(choice integer (const nil)))
 
 (define-erc-module scrolltobottom nil
-  "This mode causes the prompt to stay at the end of the window.
-You have to activate or deactivate it in already created windows
-separately."
-  ((add-hook 'erc-mode-hook 'erc-add-scroll-to-bottom))
-  ((remove-hook 'erc-mode-hook 'erc-add-scroll-to-bottom)))
+  "This mode causes the prompt to stay at the end of the window."
+  ((add-hook 'erc-mode-hook 'erc-add-scroll-to-bottom)
+   (dolist (buffer (erc-buffer-list))
+     (with-current-buffer buffer
+       (erc-add-scroll-to-bottom))))
+  ((remove-hook 'erc-mode-hook 'erc-add-scroll-to-bottom)
+   (dolist (buffer (erc-buffer-list))
+     (with-current-buffer buffer
+       (remove-hook 'window-scroll-functions 'erc-scroll-to-bottom t)))))
 
 (defun erc-add-scroll-to-bottom ()
   "A hook function for `erc-mode-hook' to recenter output at bottom of window.
@@ -73,23 +85,23 @@ You can control which line is recentered to by customizing the
 variable `erc-input-line-position'.
 
 DISPLAY-START is ignored."
-  (if (and window (window-live-p window))
+  (if (window-live-p window)
       ;; Temporarily bind resize-mini-windows to nil so that users who have it
       ;; set to a non-nil value will not suffer from premature minibuffer
       ;; shrinkage due to the below recenter call.  I have no idea why this
       ;; works, but it solves the problem, and has no negative side effects.
       ;; (Fran Litterio, 2003/01/07)
       (let ((resize-mini-windows nil))
-	(save-selected-window
-	  (select-window window)
-	  (save-restriction
-	    (widen)
-	    (when (and erc-insert-marker
-		       (> (point) erc-insert-marker)) ; we're editing a line. Scroll.
-	      (save-excursion
-		(goto-char (point-max))
-		(recenter (or erc-input-line-position -1))
-		(sit-for 0))))))))
+        (erc-with-selected-window window
+          (save-restriction
+            (widen)
+            (when (and erc-insert-marker
+                       ;; we're editing a line. Scroll.
+                       (> (point) erc-insert-marker))
+              (save-excursion
+                (goto-char (point-max))
+                (recenter (or erc-input-line-position -1))
+                (sit-for 0))))))))
 
 ;;; Make read only
 (define-erc-module readonly nil
@@ -106,13 +118,52 @@ Put this function on `erc-insert-post-hook' and/or `erc-send-post-hook'."
   (put-text-property (point-min) (point-max) 'front-sticky t)
   (put-text-property (point-min) (point-max) 'rear-nonsticky t))
 
-;; Distingush non-commands
+;;; Move to prompt when typing text
+(define-erc-module move-to-prompt nil
+  "This mode causes the point to be moved to the prompt when typing text."
+  ((add-hook 'erc-mode-hook 'erc-move-to-prompt-setup)
+   (dolist (buffer (erc-buffer-list))
+     (with-current-buffer buffer
+       (erc-move-to-prompt-setup))))
+  ((remove-hook 'erc-mode-hook 'erc-move-to-prompt-setup)
+   (dolist (buffer (erc-buffer-list))
+     (with-current-buffer buffer
+       (remove-hook 'pre-command-hook 'erc-move-to-prompt t)))))
+
+(defun erc-move-to-prompt ()
+  "Move the point to the ERC prompt if this is a self-inserting command."
+  (when (and erc-input-marker (< (point) erc-input-marker)
+             (eq 'self-insert-command this-command))
+    (deactivate-mark)
+    (push-mark)
+    (goto-char (point-max))))
+
+(defun erc-move-to-prompt-setup ()
+  "Initialize the move-to-prompt module for XEmacs."
+  (add-hook 'pre-command-hook 'erc-move-to-prompt nil t))
+
+;;; Keep place in unvisited channels
+(define-erc-module keep-place nil
+  "Leave point above un-viewed text in other channels."
+  ((add-hook 'erc-insert-pre-hook  'erc-keep-place))
+  ((remove-hook 'erc-insert-pre-hook  'erc-keep-place)))
+
+(defun erc-keep-place (ignored)
+  "Move point away from the last line in a non-selected ERC buffer."
+  (when (and (not (eq (window-buffer (selected-window))
+                      (current-buffer)))
+             (>= (point) erc-insert-marker))
+    (deactivate-mark)
+    (goto-char (erc-beg-of-input-line))
+    (forward-line -1)))
+
+;;; Distinguish non-commands
 (defvar erc-noncommands-list '(erc-cmd-ME
-			       erc-cmd-COUNTRY
-			       erc-cmd-SV
-			       erc-cmd-SM
-			       erc-cmd-SMV
-			       erc-cmd-LASTLOG)
+                               erc-cmd-COUNTRY
+                               erc-cmd-SV
+                               erc-cmd-SM
+                               erc-cmd-SMV
+                               erc-cmd-LASTLOG)
   "List of commands that are aliases for CTCP ACTION or for erc messages.
 
 If a command's function symbol is in this list, the typed command
@@ -128,11 +179,11 @@ themselves."
 (defun erc-send-distinguish-noncommands (str)
   "If STR is an ERC non-command, set `erc-insert-this' to nil."
   (let* ((command (erc-extract-command-from-line str))
-	 (cmd-fun (and command
-		       (car command))))
+         (cmd-fun (and command
+                       (car command))))
     (when (and cmd-fun
-	       (not (string-match "\n.+$" str))
-	       (memq cmd-fun erc-noncommands-list))
+               (not (string-match "\n.+$" str))
+               (memq cmd-fun erc-noncommands-list))
       (setq erc-insert-this nil))))
 
 ;;; IRC control character processing.
@@ -277,10 +328,8 @@ The value `erc-interpret-controls-p' must also be t for this to work."
   "Fetches the right face for background color N (0-15)."
   (if (stringp n) (setq n (string-to-number n)))
   (if (not (numberp n))
-      (progn
-	(message "erc-get-bg-color-face: n is NaN: %S" n)
-	(beep)
-	'default)
+      (prog1 'default
+        (erc-error "erc-get-bg-color-face: n is NaN: %S" n))
     (when (> n 16)
       (erc-log (format "   Wrong color: %s" n))
       (setq n (mod n 16)))
@@ -293,10 +342,8 @@ The value `erc-interpret-controls-p' must also be t for this to work."
   "Fetches the right face for foreground color N (0-15)."
   (if (stringp n) (setq n (string-to-number n)))
   (if (not (numberp n))
-      (progn
-	(message "erc-get-fg-color-face: n is NaN: %S" n)
-	(beep)
-	'default)
+      (prog1 'default
+        (erc-error "erc-get-fg-color-face: n is NaN: %S" n))
     (when (> n 16)
       (erc-log (format "   Wrong color: %s" n))
       (setq n (mod n 16)))
@@ -461,11 +508,11 @@ If ARG is positive, interpretation is turned on.
 Else interpretation is turned off."
   (interactive "P")
   (cond ((and (numberp arg) (> arg 0))
-	 (setq erc-interpret-controls-p t))
-	(arg (setq erc-interpret-controls-p nil))
-	(t (setq erc-interpret-controls-p (not erc-interpret-controls-p))))
+         (setq erc-interpret-controls-p t))
+        (arg (setq erc-interpret-controls-p nil))
+        (t (setq erc-interpret-controls-p (not erc-interpret-controls-p))))
   (message "ERC color interpretation %s"
-	   (if erc-interpret-controls-p "ON" "OFF")))
+           (if erc-interpret-controls-p "ON" "OFF")))
 
 ;; Smiley
 (define-erc-module smiley nil
@@ -496,8 +543,19 @@ channel that has weird people talking in morse to each other.
 
 See also `unmorse-region'."
   (goto-char (point-min))
-  (when (re-search-forward "[.-]+\\([.-]+[/ ]\\)+[.-]+" nil t)
-    (unmorse-region (match-beginning 0) (match-end 0))))
+  (when (re-search-forward "[.-]+\\([.-]*/? *\\)+[.-]+/?" nil t)
+    (save-restriction
+      (narrow-to-region (match-beginning 0) (match-end 0))
+      ;; Turn " / " into "  "
+      (goto-char (point-min))
+      (while (re-search-forward " / " nil t)
+        (replace-match "  "))
+      ;; Turn "/ " into "/"
+      (goto-char (point-min))
+      (while (re-search-forward "/ " nil t)
+        (replace-match "/"))
+      ;; Unmorse region
+      (unmorse-region (point-min) (point-max)))))
 
 ;;; erc-occur
 (defun erc-occur (string &optional proc)
@@ -506,11 +564,13 @@ If called interactively and prefix argument is given, search on all connected
 servers.  If called from a program, PROC specifies the server process."
   (interactive
    (list (read-string "Search for: ")
-	 (if current-prefix-arg
-	     nil erc-process)))
+         (if current-prefix-arg
+             nil erc-server-process)))
   (if (fboundp 'multi-occur)
       (multi-occur (erc-buffer-list nil proc) string)
     (error "`multi-occur' is not defined as a function")))
 
 (provide 'erc-goodies)
+
+;; arch-tag: d987ae26-9e28-4c72-9596-e617309fb582
 ;;; erc-goodies.el ends here
