@@ -1,6 +1,6 @@
 ;;; erc-identd.el --- RFC1413 (identd authentication protocol) server
 
-;; Copyright (C) 2003, 2006, 2007 Free Software Foundation, Inc.
+;; Copyright (C) 2003, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: John Wiegley <johnw@gnu.org>
 ;; Keywords: comm, processes
@@ -9,7 +9,7 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
@@ -74,7 +74,8 @@ This can be either a string or a number."
 		     (format "%s, %s : USERID : %s : %s\n"
 			     port-on-server port-on-client
 			     system-type (user-login-name)))
-	(process-send-eof erc-identd-process)))))
+	(stop-process erc-identd-process)
+	(delete-process proc)))))
 
 ;;;###autoload
 (defun erc-identd-start (&optional port)
