@@ -1,6 +1,7 @@
 ;;; erc-match.el --- Highlight messages matching certain regexps
 
-;; Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+;; Copyright (C) 2002, 2003, 2004, 2005, 2006,
+;;   2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: Andreas Fuchs <asf@void.at>
 ;; Keywords: comm, faces
@@ -10,7 +11,7 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
@@ -298,7 +299,7 @@ Completion is performed on the optional alist COMPLETIONS."
 		(lambda (x)
 		  (not (erc-member-ignore-case (car x) (symbol-value list)))))))
     (if (erc-member-ignore-case entry (symbol-value list))
-	(error (format "\"%s\" is already on the list" entry))
+	(error "\"%s\" is already on the list" entry)
       (set list (cons entry (symbol-value list))))))
 
 (defun erc-remove-entry-from-list (list prompt)
@@ -529,18 +530,18 @@ Use this defun with `erc-insert-modify-hook'."
 
 (defun erc-log-matches (match-type nickuserhost message)
   "Log matches in a separate buffer, determined by MATCH-TYPE.
-The behaviour of this function is controlled by the variables
-`erc-log-matches-types-alist' and `erc-log-matches-flag'. Specify the
-match types which should be logged in the former, and
-deactivate/activate match logging in the latter. See
-`erc-log-match-format'."
+The behavior of this function is controlled by the variables
+`erc-log-matches-types-alist' and `erc-log-matches-flag'.
+Specify the match types which should be logged in the former,
+and deactivate/activate match logging in the latter.
+See `erc-log-match-format'."
   (let  ((match-buffer-name (cdr (assq match-type
 				       erc-log-matches-types-alist)))
 	 (nick (nth 0 (erc-parse-user nickuserhost))))
     (when (and
 	   (or (eq erc-log-matches-flag t)
 	       (and (eq erc-log-matches-flag 'away)
-		    erc-away))
+		    (erc-away-time)))
 	   match-buffer-name)
       (let ((line (format-spec erc-log-match-format
 		   (format-spec-make
@@ -566,13 +567,13 @@ deactivate/activate match logging in the latter. See
       (unless buffer-already
 	(insert " == Type \"q\" to dismiss messages ==\n")
 	(erc-view-mode-enter nil (lambda (buffer)
-				   (when (y-or-n-p "Discard messages?")
+				   (when (y-or-n-p "Discard messages? ")
 				     (kill-buffer buffer)))))
       buffer)))
 
 (defun erc-log-matches-come-back (proc parsed)
   "Display a notice that messages were logged while away."
-  (when (and erc-away
+  (when (and (erc-away-time)
 	     (eq erc-log-matches-flag 'away))
     (mapc
      (lambda (match-type)
@@ -583,7 +584,7 @@ deactivate/activate match logging in the latter. See
 				  (with-current-buffer buffer
 				    (get-text-property (1- (point-max))
 						       'timestamp))))
-		  (away-time     (erc-emacs-time-to-erc-time erc-away)))
+		  (away-time (erc-emacs-time-to-erc-time (erc-away-time))))
 	     (when (and away-time last-msg-time
 			(erc-time-gt last-msg-time away-time))
 	       (erc-display-message
