@@ -1,6 +1,6 @@
 ;;; erc-nicklist.el --- Display channel nicknames in a side buffer.
 
-;; Copyright (C) 2004, 2005, 2006 Free Software Foundation, Inc.
+;; Copyright (C) 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Filename: erc-nicklist.el
 ;; Author: Lawrence Mitchell <wence@gmx.li>
@@ -11,7 +11,7 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
@@ -29,7 +29,7 @@
 ;; This provides a minimal mIRC style nicklist buffer for ERC.  To
 ;; activate, do M-x erc-nicklist RET in the channel buffer you want
 ;; the nicklist to appear for.  To close and quit the nicklist
-;; buffer, do M-x erc-nicklist-quit RET.
+;; buffer, do M-x erc-nicklist-quit RET from within the nicklist buffer.
 ;;
 ;; TODO:
 ;; o Somehow associate nicklist windows with channel windows so they
@@ -93,19 +93,21 @@ By \"chat medium\", we mean IRC, AOL, MSN, ICQ, etc."
   :type 'boolean)
 
 (defcustom erc-nicklist-icons-directory
-  (concat default-directory "images/")
+  (let ((dir (locate-library "erc-nicklist.el")))
+    (when dir
+      (concat (file-name-directory dir) "images/")))
   "*Directory of the PNG files for chat icons.
 Icons are displayed if `erc-nicklist-use-icons' is non-nil."
   :group 'erc-nicklist
-  :type 'string)
+  :type 'directory)
 
 (defcustom erc-nicklist-voiced-position 'bottom
   "*Position of voiced nicks in the nicklist.
 The value can be `top', `bottom' or nil (don't sort)."
   :group 'erc-nicklist
   :type  '(choice
-	   (const :tag "Top" 'top)
-	   (const :tag "Bottom" 'bottom)
+	   (const :tag "Top" top)
+	   (const :tag "Bottom" bottom)
 	   (const :tag "Mixed" nil)))
 
 (defcustom erc-nicklist-window-size 20.0
@@ -207,7 +209,9 @@ Seach for the BBDB record of this contact.  If not found, return nil."
 	   (channels (erc-server-user-buffers server-user))
 	   (op       (erc-channel-user-op channel-user))
 	   (voice    (erc-channel-user-voice channel-user))
-	   (bbdb-nick (erc-nicklist-search-for-nick (concat login "@" host)))
+	   (bbdb-nick (or (erc-nicklist-search-for-nick
+			   (concat login "@" host))
+			  ""))
 	   (away-status (if voice "" "\n(Away)"))
 	   (balloon-text (concat bbdb-nick (if (string= "" bbdb-nick)
 					       "" "\n")
@@ -406,6 +410,7 @@ list has all the voiced users according to
 ;; Local Variables:
 ;; indent-tabs-mode: t
 ;; tab-width: 8
+;; coding: utf-8
 ;; End:
 
 ;; arch-tag: db37a256-87a7-4544-bd90-e5f16c9f5ca5
