@@ -1,24 +1,26 @@
 ;;; erc-notify.el --- Online status change notification
 
-;; Copyright (C) 2002,2003,2004 Free Software Foundation, Inc.
+;; Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: Mario Lang <mlang@lexx.delysid.org>
 ;; Keywords: comm
 
-;; This file is free software; you can redistribute it and/or modify
+;; This file is part of GNU Emacs.
+
+;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
-;; This file is distributed in the hope that it will be useful,
+;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with GNU Emacs; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -28,8 +30,9 @@
 ;;; Code:
 
 (require 'erc)
-(require 'erc-nets)
+(require 'erc-networks)
 (eval-when-compile
+ (require 'cl)
  (require 'pcomplete))
 
 ;;;; Customizable variables
@@ -39,7 +42,8 @@
   :group 'erc)
 
 (defcustom erc-notify-list nil
-  "*List of nicknames you want to be notified about online/offline status change."
+  "*List of nicknames you want to be notified about online/offline
+status change."
   :group 'erc-notify
   :type '(repeat string))
 
@@ -107,17 +111,18 @@ changes."
 ;;;; Timer handler
 
 (defun erc-notify-timer (now)
-  (when (and erc-notify-list
+  (when (and erc-server-connected
+	     erc-notify-list
 	     (> (erc-time-diff
 		 erc-last-ison-time now)
 		erc-notify-interval))
     (erc-once-with-server-event
      303
      '(let* ((server (erc-response.sender parsed))
-	     (ison-list (delete "" (split-string (erc-response.contents parsed))))
+	     (ison-list (delete "" (split-string
+				    (erc-response.contents parsed))))
 	     (new-list ison-list)
-	     (old-list (with-current-buffer (erc-server-buffer)
-			 erc-last-ison)))
+	     (old-list (erc-with-server-buffer erc-last-ison)))
 	(while new-list
 	  (when (not (erc-member-ignore-case (car new-list) old-list))
 	    (run-hook-with-args 'erc-notify-signon-hook server (car new-list))
@@ -134,7 +139,7 @@ changes."
 	  (setq old-list (cdr old-list)))
 	(setq erc-last-ison ison-list)
 	t))
-    (erc-send-command
+    (erc-server-send
      (concat "ISON " (mapconcat 'identity erc-notify-list " ")))
     (setq erc-last-ison-time now)))
 
@@ -147,7 +152,8 @@ to `erc-last-ison' to prevent any further notifications."
 	       (not (erc-member-ignore-case nick erc-last-ison)))
       (add-to-list 'erc-last-ison nick)
       (run-hook-with-args 'erc-notify-signon-hook
-			  erc-announced-server-name nick)
+			  (or erc-server-announced-name erc-session-server)
+			  nick)
       (erc-display-message
        parsed 'notice proc
        'notify_on ?n nick ?m (erc-network-name)))
@@ -162,7 +168,8 @@ to `erc-last-ison' to prevent any further notifications."
 	       (not (erc-member-ignore-case nick erc-last-ison)))
       (add-to-list 'erc-last-ison nick)
       (run-hook-with-args 'erc-notify-signon-hook
-			  erc-announced-server-name nick)
+			  (or erc-server-announced-name erc-session-server)
+			  nick)
       (erc-display-message
        parsed 'notice proc
        'notify_on ?n nick ?m (erc-network-name)))
@@ -175,12 +182,13 @@ nick from `erc-last-ison' to prevent any further notifications."
   (let ((nick (erc-extract-nick (erc-response.sender parsed))))
     (when (and (erc-member-ignore-case nick erc-notify-list)
 	       (erc-member-ignore-case nick erc-last-ison))
-      (setq erc-last-ison (delete (find nick erc-last-ison
-					:test #'(lambda (x y)
-						  (string= (erc-downcase x) (erc-downcase y))))
-				  erc-last-ison))
+      (setq erc-last-ison (erc-delete-if `(lambda (el)
+					    (string= ,(erc-downcase nick)
+						     (erc-downcase el)))
+					 erc-last-ison))
       (run-hook-with-args 'erc-notify-signoff-hook
-			  erc-announced-server-name nick)
+			  (or erc-server-announced-name erc-session-server)
+			  nick)
       (erc-display-message
        parsed 'notice proc
        'notify_off ?n nick ?m (erc-network-name)))
@@ -196,7 +204,7 @@ with args, toggle notify status of people."
   (cond
    ((null args)
     ;; Print current notificated people (online)
-    (let ((ison (with-current-buffer (erc-server-buffer) erc-last-ison)))
+    (let ((ison (erc-with-server-buffer erc-last-ison)))
       (if (not ison)
 	  (erc-display-message
 	   nil 'notice 'active "No ison-list yet!")
@@ -205,20 +213,23 @@ with args, toggle notify status of people."
 	 'notify_current ?l ison))))
    ((string= (car args) "-l")
     (erc-display-message nil 'notice 'active
-			 'notify_list ?l (mapconcat 'identity erc-notify-list " ")))
+			 'notify_list ?l (mapconcat 'identity erc-notify-list
+						    " ")))
    (t
     (while args
       (if (erc-member-ignore-case (car args) erc-notify-list)
 	  (progn
 	    (setq erc-notify-list (delete (car args) erc-notify-list))
-	    ;; Remove the nick from the value of erc-last-ison in every server buffer.
-	    ;; This prevents seeing a signoff notification for a nick that you have
-	    ;; just _removed_ from your notify list.
+	    ;; Remove the nick from the value of erc-last-ison in
+	    ;; every server buffer.  This prevents seeing a signoff
+	    ;; notification for a nick that you have just _removed_
+	    ;; from your notify list.
 	    (dolist (buf (erc-buffer-list))
 	      (with-current-buffer buf
 		(if (erc-server-buffer-p)
 		    (setq erc-last-ison (delete (car args) erc-last-ison))))))
-	(setq erc-notify-list (cons (erc-string-no-properties (car args)) erc-notify-list)))
+	(setq erc-notify-list (cons (erc-string-no-properties (car args))
+				    erc-notify-list)))
       (setq args (cdr args)))
     (erc-display-message
      nil 'notice 'active
@@ -234,3 +245,10 @@ with args, toggle notify status of people."
 (provide 'erc-notify)
 
 ;;; erc-notify.el ends here
+;;
+;; Local Variables:
+;; indent-tabs-mode: t
+;; tab-width: 8
+;; End:
+
+;; arch-tag: 0fb19dd0-1359-458a-89b7-81dc195a588e
