@@ -1,21 +1,23 @@
 ;; erc-page.el - CTCP PAGE support for ERC
-;;
-;; Copyright (C)  2002  Alexander L. Belikoff (alexander@belikoff.net)
-;;
-;; This program is free software; you can redistribute it and/or
-;; modify it under the terms of the GNU General Public License
-;; as published by the Free Software Foundation; either version 2
-;; of the License, or (at your option) any later version.
-;;
-;; This program is distributed in the hope that it will be useful,
+
+;; Copyright (C) 2002, 2004, 2006, 2007, 2008 Free Software Foundation
+
+;; This file is part of GNU Emacs.
+
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
+
+;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
-;;
+
 ;; You should have received a copy of the GNU General Public License
-;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-;; 02111-1307, USA.
+;; along with GNU Emacs; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -35,6 +37,10 @@
 
 (erc-define-catalog-entry 'english 'CTCP-PAGE "Page from %n (%u@%h): %m")
 
+(defgroup erc-page nil
+  "React to CTCP PAGE messages."
+  :group 'erc)
+
 (defcustom erc-page-function nil
   "A function to process a \"page\" request.
 If nil, this prints the page message in the minibuffer and calls
@@ -68,7 +74,7 @@ inserted into the server buffer."
   (when (and erc-page-mode
 	     (string-match "PAGE\\(\\s-+.*\\)?$" msg))
     (let* ((m (match-string 1 msg))
-	   (page-msg (if m (erc-interpret-controls (substring m 1))
+	   (page-msg (if m (erc-controls-interpret (substring m 1))
 		       "[no message]"))
 	   text)
       (if m (setq m (substring m 1)))
@@ -78,7 +84,7 @@ inserted into the server buffer."
       (if erc-page-function
 	  (funcall erc-page-function nick page-msg)
 	;; if no function is defined
-	(message text)
+	(message "%s" text)
 	(beep))
       ;; insert text into buffer
       (erc-display-message
@@ -89,11 +95,20 @@ inserted into the server buffer."
   "Send a CTCP page to the user given as the first word in LINE.
 The rest of LINE is the message to send.  Note that you will only
 receive pages if `erc-page-mode' is on."
-  (when (string-match "^\\s-*\\(\\S-+\\)\\s-*\\s-*\\(\\S-+\\)" line)
+  (when (string-match "^\\s-*\\(\\S-+\\) ?\\(.*\\)" line)
     (let ((nick (match-string 1 line))
 	  (msg (match-string 2 line)))
-      (erc-cmd-CTCP (format "%s PAGE %s" nick msg)))))
+      (erc-cmd-CTCP nick "PAGE" msg))))
+
+(put 'erc-cmd-PAGE 'do-not-parse-args t)
 
 (provide 'erc-page)
 
 ;;; erc-page.el ends here
+;;
+;; Local Variables:
+;; indent-tabs-mode: t
+;; tab-width: 8
+;; End:
+
+;; arch-tag: 82fd2e0e-6060-4dd2-9788-8c1411e844de
